@@ -7,7 +7,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-10-11'; # DATE
 our $DIST = 'Text-Table-HTML'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 sub _encode {
     state $load = do { require HTML::Entities };
@@ -25,9 +25,9 @@ sub table {
 
     push @table, "<table>\n";
 
-    if (defined $params{title}) {
+    if (defined $params{caption}) {
         require HTML::Entities;
-        push @table, "<caption>".HTML::Entities::encode_entities($params{title})."</caption>\n";
+        push @table, "<caption>".HTML::Entities::encode_entities($params{caption})."</caption>\n";
     }
 
     # then the data
@@ -116,7 +116,7 @@ Text::Table::HTML - Generate HTML table
 
 =head1 VERSION
 
-This document describes version 0.008 of Text::Table::HTML (from Perl distribution Text-Table-HTML), released on 2022-10-11.
+This document describes version 0.009 of Text::Table::HTML (from Perl distribution Text-Table-HTML), released on 2022-10-11.
 
 =head1 SYNOPSIS
 
@@ -170,7 +170,7 @@ content) or hashref (with key C<text> to contain the cell text or C<raw_html> to
 contain the cell's raw HTML which won't be escaped further), and optionally
 attributes too like C<rowspan>, C<colspan>).
 
-=item * title
+=item * caption
 
 Optional. Str. If set, will add an HTML C<< <caption> >> element to set the
 table caption.
